### R code from vignette source 'categoryCompare_vignette.Rnw'

###################################################
### code chunk number 1: categoryCompare_vignette.Rnw:63-64
###################################################
options(width=60, continue=" ")


###################################################
### code chunk number 2: loadPackages
###################################################
library("affy")
library("hgu95av2.db")
library("genefilter")
library("estrogen")
library("limma")


###################################################
### code chunk number 3: setupData
###################################################
datadir <- system.file("extdata", package = "estrogen")
pd <- read.AnnotatedDataFrame(file.path(datadir,"estrogen.txt"), 
		header = TRUE, sep = "", row.names = 1)
pData(pd)


###################################################
### code chunk number 4: normalizeArrays
###################################################
currDir <- getwd()
setwd(datadir)
a <- ReadAffy(filenames=rownames(pData(pd)), phenoData = pd, verbose = TRUE)
eData <- rma(a)
setwd(currDir)


###################################################
### code chunk number 5: eset10
###################################################
e10 <- eData[, eData$time.h == 10]
e10 <- nsFilter(e10, remove.dupEntrez=TRUE, var.filter=FALSE, 
	      feature.exclude="^AFFX")$eset

e10$estrogen <- factor(e10$estrogen)
d10 <- model.matrix(~0 + e10$estrogen)
colnames(d10) <- unique(e10$estrogen)
fit10 <- lmFit(e10, d10)
c10 <- makeContrasts(present - absent, levels=d10)
fit10_2 <- contrasts.fit(fit10, c10)
eB10 <- eBayes(fit10_2)
table10 <- topTable(eB10, number=nrow(e10), p.value=1, adjust.method="BH")
table10$Entrez <- unlist(mget(rownames(table10), hgu95av2ENTREZID, ifnotfound=NA))


###################################################
### code chunk number 6: eset48
###################################################
e48 <- eData[, eData$time.h == 48]
e48 <- nsFilter(e48, remove.dupEntrez=TRUE, var.filter=FALSE, 
	      feature.exclude="^AFFX" )$eset

e48$estrogen <- factor(e48$estrogen)
d48 <- model.matrix(~0 + e48$estrogen)
colnames(d48) <- unique(e48$estrogen)
fit48 <- lmFit(e48, d48)
c48 <- makeContrasts(present - absent, levels=d48)
fit48_2 <- contrasts.fit(fit48, c48)
eB48 <- eBayes(fit48_2)
table48 <- topTable(eB48, number=nrow(e48), p.value=1, adjust.method="BH")
table48$Entrez <- unlist(mget(rownames(table48), hgu95av2ENTREZID, ifnotfound=NA))


###################################################
### code chunk number 7: universe
###################################################
gUniverse <- unique(union(table10$Entrez, table48$Entrez))


###################################################
### code chunk number 8: geneList
###################################################
library("categoryCompare")
library("GO.db")
library("KEGG.db")

# load the saved data with the package
# data(ccData)

g10 <- unique(table10$Entrez[table10$adj.P.Val < 0.05])
g48 <- unique(table48$Entrez[table48$adj.P.Val < 0.05])


###################################################
### code chunk number 9: compList
###################################################
list10 <- list(genes=g10, universe=gUniverse, annotation='org.Hs.eg.db')
list48 <- list(genes=g48, universe=gUniverse, annotation='org.Hs.eg.db')

geneLists <- list(T10=list10, T48=list48)
geneLists <- new("ccGeneList", geneLists, ccType=c("BP","KEGG"))
fdr(geneLists) <- 0 # this speeds up the calculations for demonstration
geneLists


###################################################
### code chunk number 10: enrichList
###################################################
enrichLists <- ccEnrich(geneLists)
enrichLists


###################################################
### code chunk number 11: pvalAdjust
###################################################
pvalueCutoff(enrichLists$BP) <- 0.001
enrichLists


###################################################
### code chunk number 12: ccOptions
###################################################
ccOpts <- new("ccOptions", listNames=names(geneLists), outType='none')
ccOpts


###################################################
### code chunk number 13: ccResults
###################################################
ccResults <- ccCompare(enrichLists,ccOpts)
ccResults


###################################################
### code chunk number 14: ExamineResultsBP
###################################################
cw.BP <- ccOutCyt(ccResults$BP,ccOpts)


###################################################
### code chunk number 15: breakEdges
###################################################
breakEdges(cw.BP,0.2)
breakEdges(cw.BP,0.4)
breakEdges(cw.BP,0.6)
breakEdges(cw.BP,0.8)


###################################################
### code chunk number 16: categoryCompare_vignette.Rnw:236-237
###################################################
RCytoscape::deleteWindow(cw.BP)


###################################################
### code chunk number 17: GOHierarchical
###################################################
graphType(enrichLists$BP) <- "hierarchical"
ccResultsBPHier <- ccCompare(enrichLists$BP, ccOpts)


###################################################
### code chunk number 18: categoryCompare_vignette.Rnw:256-257
###################################################
ccResultsBPHier


###################################################
### code chunk number 19: categoryCompare_vignette.Rnw:259-260
###################################################
cw.BP2 <- ccOutCyt(ccResultsBPHier, ccOpts, "BPHier")


###################################################
### code chunk number 20: categoryCompare_vignette.Rnw:262-263
###################################################
RCytoscape::deleteWindow(cw.BP2)


###################################################
### code chunk number 21: categoryCompare_vignette.Rnw:279-280
###################################################
cw.KEGG <- ccOutCyt(ccResults$KEGG,ccOpts)


###################################################
### code chunk number 22: categoryCompare_vignette.Rnw:282-283
###################################################
RCytoscape::deleteWindow(cw.KEGG)


###################################################
### code chunk number 23: categoryCompare_vignette.Rnw:300-301
###################################################
sessionInfo()


